summaryrefslogtreecommitdiff
path: root/src/mongo/db/auth/authorization_session.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/auth/authorization_session.h')
-rw-r--r--src/mongo/db/auth/authorization_session.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/auth/authorization_session.h b/src/mongo/db/auth/authorization_session.h
index 6c32fa697ae..92e4e6f6552 100644
--- a/src/mongo/db/auth/authorization_session.h
+++ b/src/mongo/db/auth/authorization_session.h
@@ -88,8 +88,8 @@ namespace mongo {
// Gets an iterator over the names of all authenticated users stored in this manager.
UserNameIterator getAuthenticatedUserNames();
// Returns a string representing all logged-in users on the current session.
// WARNING: this string will contain NUL bytes so don't call c_str()!
std::string getAuthenticatedUserNamesToken();
// Removes any authenticated principals whose authorization credentials came from the given
@@ -160,7 +160,7 @@ namespace mongo {
// Like isAuthorizedForPrivilege, above, except returns true if the session is authorized
// for all of the listed privileges.
- bool isAuthorizedForPrivileges(const vector<Privilege>& privileges);
+ bool isAuthorizedForPrivileges(const std::vector<Privilege>& privileges);
// Utility function for isAuthorizedForPrivilege(Privilege(resource, action)).
bool isAuthorizedForActionsOnResource(const ResourcePattern& resource, ActionType action);
@@ -88,8 +88,8 @@ namespace mongo {
// Gets an iterator over the names of all authenticated users stored in this manager.
UserNameIterator getAuthenticatedUserNames();
- // Returns a string representing all logged-in users on the current session.
- // WARNING: this string will contain NUL bytes so don't call c_str()!
+ // Returns a std::string representing all logged-in users on the current session.
+ // WARNING: this std::string will contain NUL bytes so don't call c_str()!
std::string getAuthenticatedUserNamesToken();
// Removes any authenticated principals whose authorization credentials came from the given